/* 
 *  Licensed Materials - Property of IBM 
 *  Component IBM Rational ROSE_RT BUILD : TARGET_RTS 
 *  (c) Copyright IBM Corporation 1991, 2005 All Rights Reserved. 
 */ 

#ifndef	__RTDRtsCompatibility_h__
#define	__RTDRtsCompatibility_h__ included

/*	INTRODUCTION
 *
 *	This file is used to verify that a Rose for Real-Time Target RTS library
 *	is compatible with the installed Connexis libraries.  Once compatibility
 *	has been verified, this file does not need to be part of the component's
 *	build.
 *
 *	HOW TO USE THIS FILE:
 *
 *	- Open the component specification of the component you wish to verify.
 *  - Add "RTDRtsCompatibility.h" to the external inclusions of the component
 *    and verify that "$(CONNEXIS_INCLUDE)" is specified as part of the
 *	  component inclusion path
 *	- Set the "Target" and "Library Set" attributes to select the TargetRTS
 *    and Connexis libraries you will be linking with
 *	- if you are verifying the "minimal" compatibility with the minimal
 *	  Connexis libraries, add the define RTD_CHECK_MINIMAL to the compiler
 *    flags attribute (ex.: /D RTD_CHECK_MINIMAL, or -D RTD_CHECK_MINIMAL)
 *	- if you are verifying compatibility with the standard versions of the
 *    Connexis libraries, add the define RTD_CHECK_STANDARD to the compiler
 *    flags attribute (ex.: /D RTD_CHECK_STANDARD, or -D RTD_CHECK_STANDARD)
 *
 *	EXPECTED OUTPUT
 *
 *	If any imcompatibilities are detected, an error is generated by the
 *	preprocessor at compilation time.
 */

#include <RTTarget.h>

//	Minimum configuration compatibility checking
//
#if defined (RTD_CHECK_MINIMAL) && ! defined(RTD_CHECK_STANDARD)

#  if defined(OTRTSDEBUG) && (OTRTSDEBUG != DEBUG_NONE)
#  error OTRTSDEBUG must be set to DEBUG_NONE in the minimum configuration
#  endif

#  if defined(RTTYPECHECK_SEND) && (RTTYPECHECK_SEND != RTTYPECHECK_DONT)
#  error RTTYPECHECK_SEND must be set to RTTYPECHECK_DONT in the minimal configuration
#  endif

#  if defined(RTTYPECHECK_RECEIVE) && (RTTYPECHECK_RECEIVE != RTTYPECHECK_DONT)
#  error RTTYPECHECK_RECEIVE must be set to RTTYPECHECK_DONT in the minimal configuration
#  endif
#endif

//	Standard configuration compatibility checking
//
#if defined (RTD_CHECK_STANDARD) && ! defined(RTD_CHECK_MINIMAL)

#  if defined(OTRTSDEBUG) && (OTRTSDEBUG != DEBUG_VERBOSE)
#  error OTRTSDEBUG must be set to DEBUG_VERBOSE in the standard configuration
#  endif

#  if defined(RTTYPECHECK_SEND) && (RTTYPECHECK_SEND != RTTYPECHECK_WARN)
#  error RTTYPECHECK_SEND must be set to RTTYPECHECK_WARN in the standard configuration
#  endif

#  if defined(RTTYPECHECK_RECEIVE) && (RTTYPECHECK_RECEIVE != RTTYPECHECK_WARN)
#  error RTTYPECHECK_RECEIVE must be set to RTTYPECHECK_WARN in the standard configuration
#  endif
#endif

#if ! defined(RTD_CHECK_STANDARD) && ! defined (RTD_CHECK_MINIMAL)
#error	Please specify a configuration (RTD_CHECK_MINIMAL / RTD_CHECK_STANDARD)
#endif


//	Configuration independant compatibility checking
//
#if defined(EXTERNAL_LAYER) && (EXTERNAL_LAYER != 0)
#error The extenal layer must be disabled
#endif

#if defined(DEFER_IN_ACTOR) && (DEFER_IN_ACTOR != 0)
#error DEFER_IN_ACTOR must be set to 0
#endif

#if defined(HAVE_INET) && (HAVE_INET != 1)
#error HAVE_INET must be set to 1
#endif

#if defined(INTEGER_POSTFIX) && (INTEGER_POSTFIX != 1)
#error INTEGER_POSTFIX must be set to 1
#endif

#if defined(LOG_MESSAGE) && (LOG_MESSAGE != 1)
#error LOG_MESSAGE must be set to 1
#endif
 
#if defined(OBJECT_DECODE) && (OBJECT_DECODE != 1)
#error OBJECT_DECODE must be set to 1
#endif

#if defined(OBJECT_ENCODE) && (OBJECT_ENCODE != 1)
#error OBJECT_ENCODE must be set to 1
#endif

#if defined(PURIFY) && (PURIFY != 0)
#error PURIFY must be set to 0
#endif

#if defined(RTS_COMPATIBLE) && (RTS_COMPATIBLE != 520)
#error Connexis is compatible with Target RTS base revision 5.2	and higher
#endif

#if defined(RTS_COUNT) && (RTS_COUNT != 0)
#error RTS_COUNT must be set to 0
#endif

#if defined(RTS_INLINES) && (RTS_INLINES != 1)
#error RTS_INLINES must be set to 1
#endif

#if defined(RTFRAME_USE_FREELIST) && (RTFRAME_USE_FREELIST != 1)
#error RTFRAME_USE_FREELIST must be set to 1
#endif

#if defined(RTMESSAGE_PAYLOAD_SIZE) && (RTMESSAGE_PAYLOAD_SIZE != 76)
#error RTMESSAGE_PAYLOAD_SIZE must be set to 76
#endif

#if defined(RTREAL_INCLUDED) && (RTREAL_INCLUDED != 1)
#error RTREAL_INCLUDED must be set to 1
#endif

#if defined(RTUseBitFields) && (RTUseBitFields != 0)
#error RTUseBitFields must be set to 0
#endif

#if defined(RTStateId_MaxSize) && (RTStateId_MaxSize != 2)
#error RTStateId_MaxSize must be set to 2
#endif

#if ! defined(INLINE_CHAINS)
#error INLINE_CHAINS must be defined
#endif

#if ! defined (INLINE_METHODS)
#error INLINE_METHODS must be defined
#endif

#if defined(RTRUNTIMEBC) && (RTRUNTIMEBC != 0)
#error RTRUNTIMEBC must be set to 0
#endif


#endif	// __RTDRtsCompatibility_h__
