/*
 * Licensed Materials - Property of IBM
 * Counter Sample
 *  Copyright IBM Corporation 2003, 2010. All Rights Reserved.
 * U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 * Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement.
 */
package $packageName$;

import java.text.MessageFormat;
import java.util.Iterator;
import java.util.List;

import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

import com.ibm.xtools.modeler.ui.UMLModeler;

/**
 * This action delegate counts the number of modeling elements owned by the
 * selected element.
 * 
 * @see IWorkbenchWindowActionDelegate
 */
public class $className$
    implements IWorkbenchWindowActionDelegate {

    /**
     * The shell this action delegate was initialized for
     */
    private Shell shell;

    /**
     * Constructor
     */
    public $className$() {
        // No-op
    }

    /**
     * Counts number of modeling elements in selection
     * 
     * @see IWorkbenchWindowActionDelegate#run
     */
    public void run(IAction action) {

        try {
            final String strMessage[] = {null};

            UMLModeler.getEditingDomain().runExclusive(new Runnable() {

                /*
                 * (non-Javadoc)
                 * 
                 * @see java.lang.Runnable#run()
                 */
                public void run() {

                    int count = 0;

                    // Get selection from the window
                    List elements = UMLModeler.getUMLUIHelper()
                        .getSelectedElements();

                    for (Iterator i = elements.iterator(); i.hasNext();) {
                        EObject eObject = (EObject) i.next();

                        // Accumulate number of owned element
                        count += countOwnedContents(eObject);
                    }

                    // Output results
                    strMessage[0] = MessageFormat
                        .format(
                            "The selection contains {0} sub-elements.\n\nNOTE: Not all sub-elements are displayed by the user interface.", //$$NON-NLS-1$$
                            new Object[] {String.valueOf(count)});

                }
            });

            MessageDialog.openInformation(shell,
                "UML Modeler Sub-Element Counter", strMessage[0]); //$$NON-NLS-1$$

        } catch (InterruptedException e) {

            MessageDialog.openInformation(shell,
                "UML Modeler Sub-Element Counter", //$$NON-NLS-1$$
                "The operation was interrupted"); //$$NON-NLS-1$$
        }

    }

    /**
     * Calculates the number of modeling elements owned by the specified object
     * 
     * @param eObject
     *            The modeling element to calculate the number of owned elements
     *            from
     * @return The number of owned modeling element
     */
    private int countOwnedContents(final EObject eObject) {

        int count = 0;

        TreeIterator contents = eObject.eAllContents();

        while (contents.hasNext()) {
            contents.next();
            count++;
        }

        return count;
    }

    /**
     * @see IWorkbenchWindowActionDelegate#selectionChanged
     */
    public void selectionChanged(IAction action, ISelection selection) {
        // No-op
    }

    /**
     * @see IWorkbenchWindowActionDelegate#dispose
     */
    public void dispose() {
        // No-op
    }

    /**
     * @see IWorkbenchWindowActionDelegate#init
     */
    public void init(IWorkbenchWindow window) {
        shell = window.getShell();
    }
}